<?php
/**
 * AmiClean/AmiSample configuration.
 *
 * @copyright Amiro.CMS. All rights reserved.
 * @category  Module
 * @package   Config_AmiClean_AmiSample
 * @version   $Id: AmiClean_AmiSample_Frn.php 61177 2013-07-31 12:49:17Z Leontiev Anton $
 * @since     5.14.8
 */

/**
 * AmiClean/AmiSample configuration front action controller.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage Controller
 * @resource   {$modId}/module/controller/adm <code>AMI::getResource('{$modId}/module/controller/frn')*</code>
 */
class AmiClean_AmiSample_Frn extends Hyper_AmiClean_Frn{
    /**
     * Constructor.
     *
     * @param AMI_Request  $oRequest   Request object
     * @param AMI_Response $oResponse  Response object
     */
    public function __construct(AMI_Request $oRequest, AMI_Response $oResponse){
        // Redefine default body type
        if($oRequest->get('custom', false)){
            $this->setDefaultBodyType('custom');
        }

        parent::__construct($oRequest, $oResponse);

        if($this->isSpecblock()){
            $this->addComponents(array('specblock'));
            $this->addComponents(array('specblock'), array('postfix' => 'custom'));
        }
    }
}

/**
 * AmiClean/AmiSample configuration front items component.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage Controller
 * @resource   {$modId}/items/controller/frn <code>AMI::getResource('{$modId}/items/controller/frn')*</code>
 */
class AmiClean_AmiSample_ItemsFrn extends Hyper_AmiClean_ItemsFrn{
}

/**
 * AmiClean/AmiSample configuration front items body type view.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage View
 * @resource   {$modId}/items/view/frn <code>AMI::getResource('{$modId}/items/view/frn')*</code>
 */
class AmiClean_AmiSample_ItemsViewFrn extends Hyper_AmiClean_ItemsViewFrn{

    /**
     * Initialize.
     *
     * @see    AMI_View::init()
     * @return AMI_ModItemsView
     */
    public function init(){
        parent::init();

        // Init columns
        $this
            ->addColumn('id')
            ->addColumn('public')
            ->addColumnType('birth', 'date')
            ->addColumn('sublink')
            ->addColumn('nickname')
            ->addColumn('about');

        return $this;
    }
}

/**
 * AmiClean/AmiSample configuration front custom component.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage Controller
 * @resource   {$modId}/custom/controller/frn <code>AMI::getResource('{$modId}/custom/controller/frn')*</code>
 */
class AmiClean_AmiSample_CustomFrn extends Hyper_AmiClean_ComponentFrn{
    /**
     * Returns component type.
     *
     * @return string
     */
    public function getType(){
        return 'custom';
    }
}

/**
 * AmiClean/AmiSample configuration front custom body type view.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage View
 * @resource   {$modId}/custom/view/frn <code>AMI::getResource('{$modId}/custom/view/frn')*</code>
 */
class AmiClean_AmiSample_CustomViewFrn extends Hyper_AmiClean_ComponentViewFrn{
    /**
     * Returns view data.
     *
     * @return string
     */
    public function get(){
        $oList = AMI::getResourceModel($this->getModId() . '/table')->getList('id')->load();
        $aData = array(
            'items_count' => count($oList)
        );
        return $this->parse('custom_body', $aData);
    }
}

/**
 * AmiClean/AmiSample configuration front details component.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage Controller
 * @resource   {$modId}/details/controller/frn <code>AMI::getResource('{$modId}/details/controller/frn')*</code>
 */
class AmiClean_AmiSample_DetailsFrn extends AMI_ModDetails{
    /**
     * Initialization.
     *
     * @return AMI_ModComponentStub
     */
    public function init(){
        $this->bDispayView = true;
        return $this;
    }

    /**
     * Returns component view.
     *
     * @return AMI_ViewEmpty
     */
    public function getView(){
        $oView = $this->_getView('/' . $this->getType() . '/view/frn');
        return $oView;
    }
}

/**
 * AmiClean/AmiSample configuration front details body type view.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage View
 * @resource   {$modId}/details/view/frn <code>AMI::getResource('{$modId}/details/view/frn')*</code>
 */
class AmiClean_AmiSample_DetailsViewFrn extends AMI_ModDetailsView{
    /**
     * Constructor.
     */
    public function __construct(){
        $modId = $this->getModId();
        $this->tplFileName = AMI_iTemplate::TPL_MOD_PATH . '/' . $modId . '.tpl';
        $this->tplBlockName = $modId . '_details';
        $this->localeFileName = AMI_iTemplate::LNG_MOD_PATH . '/' . $modId . '.lng';
        parent::__construct();
    }

    /**
     * Returns view data.
     *
     * @return string
     */
    public function get(){
        $this->prepareFieldCallbacks();

        $aData = array();
        $aData = parent::get();
        $aData['body'] = $this->oTpl->parse($this->tplBlockName.':body_itemD', $aData);
        $aData['body'] = $this->oTpl->parse($this->tplBlockName, $aData);

        return $aData['body'];
    }
}

/**
 * AmiClean/AmiSample configuration specblock list component controller.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage Controller
 * @resource   {$modId}/specblock/controller/frn <code>AMI::getResource('{$modId}/specblock/controller/frn')*</code>
 */
class AmiClean_AmiSample_SpecblockFrn extends AMI_ModSpecblockList{
}

/**
 * AmiClean/AmiSample configuration specblock component controller.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage Controller
 * @resource   {$modId}/specblock_custom/controller/frn <code>AMI::getResource('{$modId}/specblock_custom/controller/frn')*</code>
 */
class AmiClean_AmiSample_SpecblockCustom extends AMI_ModSpecblock{
    /**
     * Returns component view.
     *
     * @return AMI_View
     */
    public function getView(){
        return $this->_getView('/' . $this->getType() . '_custom/view/frn');
    }
}

/**
 * AmiClean/AmiSample configuration specblock list component view.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage View
 * @resource   {$modId}/specblock/view/frn <code>AMI::getResource('{$modId}/specblock/view/frn')*</code>
 */
class AmiClean_AmiSample_SpecblockListViewFrn extends AMI_ModSpecblockListView{
    /**
     * Initialization.
     *
     * @return AMI_ModSpecblockView
     */
    public function init(){
        $this
            ->addColumn('id')
            ->addColumn('nickname');

        return $this;
    }
}

/**
 * AmiClean/AmiSample configuration specblock component view.
 *
 * @package    Config_AmiClean_AmiSample
 * @subpackage View
 * @resource   {$modId}/specblock_custom/view/frn <code>AMI::getResource('{$modId}/specblock_custom/view/frn')*</code>
 */
class AmiClean_AmiSample_SpecblockCustomView extends AMI_View{
    /**
     * Constructor.
     */
    public function __construct(){
        // Specblock template, blockname and locale filename
        $this->tplBlockName   = $this->getModId() . '_specblock_custom';
        $this->tplFileName    = AMI_iTemplate::TPL_MOD_PATH . '/' . $this->getModId() . '_specblock_custom.tpl';
        $this->localeFileName = AMI_iTemplate::LNG_MOD_PATH . '/' . $this->getModId() . '_specblock_custom.lng';

        parent::__construct();
    }

    /**
     * Returns view data.
     *
     * @return string
     */
    public function get(){
        $aPageItemData = AMI_PageManager::getPageItemData();
        return
            $this->getTemplate()->parse(
                $this->tplBlockName . ':body',
                array(
                    'item_header' => isset($aPageItemData['header']) ? $aPageItemData['header'] : false,
                    'cat_header' => isset($aPageItemData['catHeader']) ? $aPageItemData['catHeader'] : false,
                    'time'   => date('Y-m-d H:i:s'),
                    'option' => AMI::getOption($this->getModId(), 'spec_small_option_custom')
                )
            );
    }
}
